@@ -1,3 +1,4 @@
+from datetime import date
 from sqlalchemy import ForeignKey
 from sqlalchemy.dialects.postgresql import JSONB
 from sqlalchemy.orm import Mapped, mapped_column
@@ -11,14 +12,10 @@ from sqlalchemy.types import (
     UUID as SQLAlchemyUUID,
 )
 from uuid import UUID
-from maleo.enums.identity import Gender, OptionalGender
-from maleo.enums.medical import (
-    Service as MedicalService,
-    OptionalService as OptionalMedicalService,
-)
+from maleo.enums.identity import Gender
+from maleo.enums.medical import Service as MedicalService
 from maleo.schemas.model import DataIdentifier, DataStatus, DataTimestamp
 from maleo.types.any import ListOfAny
-from maleo.types.datetime import OptionalDate
 from maleo.types.string import OptionalString
 from maleo.types.uuid import OptionalUUID
 from .enums.inference import InferenceType
@@ -32,19 +29,25 @@ class Record(DataTimestamp, DataStatus, DataIdentifier):
     user_id: Mapped[UUID] = mapped_column(
         name="user_id", type_=SQLAlchemyUUID, nullable=False
     )
-    medical_service: Mapped[OptionalMedicalService] = mapped_column(
-        name="medical_service", type_=Enum(MedicalService, name="medical_service")
+    medical_service: Mapped[MedicalService] = mapped_column(
+        name="medical_service",
+        type_=Enum(MedicalService, name="medical_service"),
+        nullable=False,
     )
-    name: Mapped[OptionalString] = mapped_column(name="name", type_=String(200))
-    gender: Mapped[OptionalGender] = mapped_column(
-        name="gender", type_=Enum(Gender, name="gender")
+    name: Mapped[str] = mapped_column(name="name", type_=String(200), nullable=False)
+    date_of_birth: Mapped[date] = mapped_column(
+        name="date_of_birth", type_=Date, nullable=False
     )
-    date_of_birth: Mapped[OptionalDate] = mapped_column(
-        name="date_of_birth", type_=Date
+    gender: Mapped[Gender] = mapped_column(
+        name="gender", type_=Enum(Gender, name="gender", nullable=False)
+    )
+    finding: Mapped[str] = mapped_column(name="finding", type_=Text, nullable=False)
+    impression: Mapped[str] = mapped_column(
+        name="impression", type_=Text, nullable=False
+    )
+    recommendation: Mapped[OptionalString] = mapped_column(
+        name="recommendation", type_=Text
     )
-    description: Mapped[OptionalString] = mapped_column(name="description", type_=Text)
-    impression: Mapped[OptionalString] = mapped_column(name="impression", type_=Text)
-    diagnosis: Mapped[str] = mapped_column(name="diagnosis", type_=Text, nullable=False)
     filename: Mapped[str] = mapped_column(name="filename", type_=Text, nullable=False)
 
 
@@ -56,8 +59,17 @@ class Inference(DataTimestamp, DataStatus, DataIdentifier):
     user_id: Mapped[UUID] = mapped_column(
         name="user_id", type_=SQLAlchemyUUID, nullable=False
     )
-    medical_service: Mapped[OptionalMedicalService] = mapped_column(
-        name="medical_service", type_=Enum(MedicalService, name="medical_service")
+    medical_service: Mapped[MedicalService] = mapped_column(
+        name="medical_service",
+        type_=Enum(MedicalService, name="medical_service"),
+        nullable=False,
+    )
+    name: Mapped[str] = mapped_column(name="name", type_=String(200), nullable=False)
+    date_of_birth: Mapped[date] = mapped_column(
+        name="date_of_birth", type_=Date, nullable=False
+    )
+    gender: Mapped[Gender] = mapped_column(
+        name="gender", type_=Enum(Gender, name="gender", nullable=False)
     )
     type: Mapped[InferenceType] = mapped_column(
         name="type", type_=Enum(InferenceType, name="xray_inference_type")
