@@ -1,3 +1,4 @@
+from datetime import date
 from pydantic import BaseModel, Field, model_validator
 from typing import (
     Annotated,
@@ -10,22 +11,33 @@ from typing import (
     Union,
 )
 from uuid import UUID
-from maleo.enums.identity import OptionalGender
-from maleo.enums.medical import OptionalService as OptionalMedicalService
+from maleo.enums.identity import Gender
+from maleo.enums.medical import Service as MedicalService
 from maleo.enums.status import DataStatus as DataStatusEnum
 from maleo.schemas.mixins.identity import DataIdentifier
 from maleo.schemas.mixins.status import DataStatus
 from maleo.schemas.mixins.timestamp import DataTimestamp
-from maleo.types.datetime import OptionalDate
 from maleo.types.string import OptionalString
 from maleo.types.uuid import OptionalUUID
+from ...schemas import FindingWithoutBox, FindingWithBox
 from ..enums.inference import (
     InferenceType,
     InferenceTypeT,
     MultiFindingClass,
     TuberculosisClass,
 )
-from .inference import FindingWithoutBox, FindingWithBox, AnyFindingT
+
+
+class MultiFindingFinding(FindingWithBox[MultiFindingClass]):
+    pass
+
+
+class TuberculosisFinding(FindingWithoutBox[TuberculosisClass]):
+    pass
+
+
+AnyXrayFinding = Union[MultiFindingFinding, TuberculosisFinding]
+AnyXrayFindingT = TypeVar("AnyXrayFindingT", bound=AnyXrayFinding)
 
 
 class RecordCoreSchema(
@@ -38,20 +50,16 @@ class RecordCoreSchema(
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
+    finding: Annotated[str, Field(..., description="Finding")]
+    impression: Annotated[str, Field(..., description="Impression")]
+    recommendation: Annotated[
+        OptionalString, Field(None, description="Recommendation")
     ] = None
-    name: Annotated[OptionalString, Field(None, description="Name", max_length=200)] = (
-        None
-    )
-    gender: Annotated[OptionalGender, Field(None, description="Gender")] = None
-    date_of_birth: Annotated[OptionalDate, Field(None, description="Date of Birth")] = (
-        None
-    )
-    description: Annotated[OptionalString, Field(None, description="Description")] = (
-        None
-    )
-    impression: Annotated[OptionalString, Field(None, description="Impression")] = None
-    diagnosis: Annotated[str, Field(..., description="Diagnosis")]
     filename: Annotated[str, Field(..., description="File's name")]
     url: Annotated[str, Field(..., description="File's URL")]
 
@@ -64,65 +72,68 @@ class GenericInferenceCoreSchema(
     DataStatus[DataStatusEnum],
     DataTimestamp,
     DataIdentifier,
-    Generic[InferenceTypeT, AnyFindingT],
+    Generic[InferenceTypeT, AnyXrayFindingT],
 ):
     organization_id: Annotated[
         OptionalUUID, Field(None, description="Organization ID")
     ] = None
     user_id: Annotated[UUID, Field(..., description="User ID")]
     medical_service: Annotated[
-        OptionalMedicalService, Field(None, description="Medical service")
-    ] = None
+        MedicalService, Field(..., description="Medical service")
+    ]
+    name: Annotated[str, Field(..., description="Name", max_length=200)]
+    gender: Annotated[Gender, Field(..., description="Gender")]
+    date_of_birth: Annotated[date, Field(..., description="Date of Birth")]
     type: Annotated[InferenceTypeT, Field(..., description="Inference's type")]
     duration: Annotated[float, Field(0.0, description="Inference's duration")] = 0.0
     findings: Annotated[
-        List[AnyFindingT],
-        Field(list[AnyFindingT](), description="Findings", min_length=1),
-    ] = list[AnyFindingT]()
+        List[AnyXrayFindingT],
+        Field(list[AnyXrayFindingT](), description="Findings", min_length=1),
+    ] = list[AnyXrayFindingT]()
 
     @model_validator(mode="after")
     def validate_findings(self) -> Self:
         if self.type is InferenceType.MULTI_FINDING:
-            for index, finding in enumerate(self.findings):
+            for finding in self.findings:
+                if not isinstance(finding, MultiFindingFinding):
+                    raise TypeError(
+                        f"Finding's type must be {MultiFindingFinding.__name__} for {InferenceType.MULTI_FINDING} inference"
+                    )
                 if finding.name not in MultiFindingClass.choices():
                     raise ValueError(
-                        f"Invalid finding's name for {InferenceType.MULTI_FINDING} inference",
-                        f"Received: {finding.name}",
-                        f"Expected: [{MultiFindingClass.choices()}]",
-                    )
-                if finding.box is None:
-                    raise ValueError(
-                        f"Attribute 'box' can not be None for {InferenceType.MULTI_FINDING} inference",
-                        f"index: {index}, id: {finding.id}, name: {finding.name}",
+                        f"Invalid finding's name for {InferenceType.MULTI_FINDING} inference, "
+                        f"Received: {finding.name}, "
+                        f"Expected: {MultiFindingClass.choices()}"
                     )
         elif self.type is InferenceType.TUBERCULOSIS:
             if len(self.findings) != 1:
                 raise ValueError(
                     f"{InferenceType.TUBERCULOSIS} inference can only have one finding"
                 )
-            for index, finding in enumerate(self.findings):
+            for finding in self.findings:
+                if not isinstance(finding, TuberculosisFinding):
+                    raise TypeError(
+                        f"Finding's type must be {TuberculosisFinding.__name__} for {InferenceType.TUBERCULOSIS} inference"
+                    )
                 if finding.name not in TuberculosisClass.choices():
                     raise ValueError(
-                        f"Invalid finding's name for {InferenceType.TUBERCULOSIS} inference",
-                        f"Received: {finding.name}",
-                        f"Expected: [{TuberculosisClass.choices()}]",
-                    )
-                if finding.box is not None:
-                    raise ValueError(
-                        f"Attribute 'box' must be None for {InferenceType.TUBERCULOSIS} inference",
-                        f"index: {index}, id: {finding.id}, name: {finding.name}",
+                        f"Invalid finding's name for {InferenceType.TUBERCULOSIS} inference, "
+                        f"Received: {finding.name}, "
+                        f"Expected: {TuberculosisClass.choices()}"
                     )
         return self
 
 
 class MultiFindingInferenceCoreSchema(
-    GenericInferenceCoreSchema[Literal[InferenceType.MULTI_FINDING], FindingWithBox]
+    GenericInferenceCoreSchema[
+        Literal[InferenceType.MULTI_FINDING], MultiFindingFinding
+    ]
 ):
     pass
 
 
 class TuberculosisInferenceCoreSchema(
-    GenericInferenceCoreSchema[Literal[InferenceType.TUBERCULOSIS], FindingWithoutBox]
+    GenericInferenceCoreSchema[Literal[InferenceType.TUBERCULOSIS], TuberculosisFinding]
 ):
     pass
 
@@ -136,7 +147,7 @@ def is_multi_finding_core_schema(
     schema: AnyInferenceCoreSchema,
 ) -> TypeGuard[MultiFindingInferenceCoreSchema]:
     return schema.type is InferenceType.MULTI_FINDING and all(
-        [isinstance(finding, FindingWithBox) for finding in schema.findings]
+        [isinstance(finding, MultiFindingFinding) for finding in schema.findings]
     )
 
 
@@ -146,7 +157,9 @@ def is_tuberculosis_core_schema(
     return (
         schema.type is InferenceType.TUBERCULOSIS
         and len(schema.findings) == 1
-        and all([isinstance(finding, FindingWithBox) for finding in schema.findings])
+        and all(
+            [isinstance(finding, TuberculosisFinding) for finding in schema.findings]
+        )
     )
 
 
@@ -197,21 +210,23 @@ class InferenceRecordsSchemaMixin(BaseModel):
 
 class GenericInferenceCompleteSchema(
     InferenceRecordsSchemaMixin,
-    GenericInferenceCoreSchema[InferenceTypeT, AnyFindingT],
-    Generic[InferenceTypeT, AnyFindingT],
+    GenericInferenceCoreSchema[InferenceTypeT, AnyXrayFindingT],
+    Generic[InferenceTypeT, AnyXrayFindingT],
 ):
     pass
 
 
 class MultiFindingInferenceCompleteSchema(
-    GenericInferenceCompleteSchema[Literal[InferenceType.MULTI_FINDING], FindingWithBox]
+    GenericInferenceCompleteSchema[
+        Literal[InferenceType.MULTI_FINDING], MultiFindingFinding
+    ]
 ):
     pass
 
 
 class TuberculosisInferenceCompleteSchema(
     GenericInferenceCompleteSchema[
-        Literal[InferenceType.TUBERCULOSIS], FindingWithoutBox
+        Literal[InferenceType.TUBERCULOSIS], TuberculosisFinding
     ]
 ):
     pass
@@ -226,7 +241,7 @@ def is_multi_finding_complete_schema(
     schema: AnyInferenceCompleteSchema,
 ) -> TypeGuard[MultiFindingInferenceCompleteSchema]:
     return schema.type is InferenceType.MULTI_FINDING and all(
-        [isinstance(finding, FindingWithBox) for finding in schema.findings]
+        [isinstance(finding, MultiFindingFinding) for finding in schema.findings]
     )
 
 
@@ -236,7 +251,9 @@ def is_tuberculosis_complete_schema(
     return (
         schema.type is InferenceType.TUBERCULOSIS
         and len(schema.findings) == 1
-        and all([isinstance(finding, FindingWithBox) for finding in schema.findings])
+        and all(
+            [isinstance(finding, TuberculosisFinding) for finding in schema.findings]
+        )
     )
 
 
